@@ -1,7 +1,7 @@
 #' Takes an emtools.species object with presence and background points, and builds a maxent model
 #'
 #' @param species An enmtools.species object
-#' @param env A raster or raster stack of environmental data.
+#' @param env A SpatRaster of environmental data.
 #' @param test.prop Proportion of data to withhold randomly for model evaluation, or "block" for spatially structured evaluation.
 #' @param nback Number of background points to draw from range or env, if background points aren't provided
 #' @param env.nback Number of points to draw from environment space for environment space discrimination metrics.
@@ -18,22 +18,20 @@
 #' @return An enmtools model object containing species name, model formula (if any), model object, suitability raster, marginal response plots, and any evaluation objects that were created.
 #'
 #' @examples
-#' \dontrun{
-#' install.extras(repos='http://cran.us.r-project.org')
-#' data(euro.worldclim)
-#' data(iberolacerta.clade)
-#' if(requireNamespace("rJava", quietly = TRUE)) {
-#'     enmtools.maxent(iberolacerta.clade$species$monticola, env = euro.worldclim)
-#' }
+#' if(check.extras("enmtools.maxent")) {
+#'     ## maxent is not working on some platforms so use try()
+#'     try(enmtools.maxent(iberolacerta.clade$species$monticola, env = euro.worldclim))
 #' }
 
 
 enmtools.maxent <- function(species, env, test.prop = 0, nback = 1000, env.nback = 10000, report = NULL, overwrite = FALSE, rts.reps = 0,  bg.source = "default", verbose = FALSE, clamp = TRUE,  corner = NA, bias = NA, ...){
 
-  check.packages("rJava")
+  assert.extras.this.fun()
 
   notes <- NULL
 
+  env <- check.raster(env, "env")
+
   species <- check.bg(species, env, nback = nback, bg.source = bg.source, verbose = verbose, bias = bias)
 
   maxent.precheck(f, species, env)
@@ -60,7 +58,7 @@ enmtools.maxent <- function(species, env, test.prop = 0, nback = 1000, env.nback
       } else if(corner < 1 | corner > 4){
         stop("corner should be an integer from 1 to 4!")
       }
-      test.inds <- get.block(species$presence.points, species$background.points)
+      test.inds <- get.block(terra::crds(species$presence.points), terra::crds(species$background.points))
       test.bg.inds <- which(test.inds$bg.grp == corner)
       test.inds <- which(test.inds$occs.grp == corner)
       test.data <- species$presence.points[test.inds,]
@@ -70,14 +68,13 @@ enmtools.maxent <- function(species, env, test.prop = 0, nback = 1000, env.nback
     }
   }
 
-  analysis.df <- rbind(species$presence.points, species$background.points)
-  analysis.df$presence <- c(rep(1, nrow(species$presence.points)), rep(0, nrow(species$background.points)))
+  analysis.df <- make_analysis.df(species)
 
   # This is a very weird hack that has to be done because dismo's evaluate and maxent function
   # fail if the stack only has one layer.
   if(length(names(env)) == 1){
     oldname <- names(env)
-    env <- stack(env, env)
+    env <- c(env, env)
     env[[2]][!is.na(env[[2]])] <- 0
     names(env) <- c(oldname, "dummyvar")
     notes <- c(notes, "Only one predictor was provided, so a dummy variable was created in order to be compatible with dismo's prediction function.")
@@ -85,24 +82,24 @@ enmtools.maxent <- function(species, env, test.prop = 0, nback = 1000, env.nback
 
   if(verbose){
     this.mx <- dismo::maxent(env, p = analysis.df[analysis.df$presence == 1,1:2], a = analysis.df[analysis.df$presence == 0,1:2], ...)
-    suitability <- predict(env, this.mx, type = "response", ...)
+    suitability <- terra::predict(env, this.mx, type = "response", na.rm = TRUE, ...)
   } else {
     invisible(capture.output(this.mx <- dismo::maxent(env, p = analysis.df[analysis.df$presence == 1,1:2], a = analysis.df[analysis.df$presence == 0,1:2], ...)))
-    invisible(capture.output(suitability <- predict(env, this.mx, type = "response", ...)))
+    invisible(capture.output(suitability <- terra::predict(env, this.mx, type = "response", na.rm = TRUE, ...)))
   }
 
   # Clamping and getting a diff layer
   clamping.strength <- NA
   if(clamp == TRUE){
     # Adding env (skipped for MX otherwise)
-    this.df <- as.data.frame(extract(env, species$presence.points))
+    this.df <- as.data.frame(terra::extract(env, species$presence.points, ID = FALSE))
 
     env <- clamp.env(this.df, env)
 
     if(verbose){
-      clamped.suitability <- predict(env, this.mx, type = "response", ...)
+      clamped.suitability <- terra::predict(env, this.mx, type = "response", na.rm = TRUE, ...)
     } else {
-      invisible(capture.output(clamped.suitability <- predict(env, this.mx, type = "response", ...)))
+      invisible(capture.output(clamped.suitability <- terra::predict(env, this.mx, type = "response", na.rm = TRUE, ...)))
     }
 
     clamping.strength <- clamped.suitability - suitability
@@ -110,13 +107,13 @@ enmtools.maxent <- function(species, env, test.prop = 0, nback = 1000, env.nback
   }
 
   if(verbose){
-    model.evaluation <-dismo::evaluate(species$presence.points[,1:2], species$background.points[,1:2],
-                                       this.mx, env)
+    model.evaluation <-dismo::evaluate(species$presence.points, species$background.points,
+                                       this.mx, env, na.rm = TRUE)
     env.model.evaluation <- env.evaluate(species, this.mx, env, n.background = env.nback)
 
   } else {
-    invisible(capture.output(model.evaluation <-dismo::evaluate(species$presence.points[,1:2], species$background.points[,1:2],
-                                       this.mx, env)))
+    invisible(capture.output(model.evaluation <-dismo::evaluate(species$presence.points, species$background.points,
+                                       this.mx, env, na.rm = TRUE)))
     invisible(capture.output(env.model.evaluation <- env.evaluate(species, this.mx, env, n.background = env.nback)))
 
   }
@@ -124,19 +121,19 @@ enmtools.maxent <- function(species, env, test.prop = 0, nback = 1000, env.nback
   # Test eval for randomly withheld data
   if(is.numeric(test.prop)){
     if(test.prop > 0 & test.prop < 1){
-      test.check <- raster::extract(env, test.data)
+      test.check <- terra::extract(env, test.data, ID = FALSE)
       test.data <- test.data[complete.cases(test.check),]
 
       temp.sp <- species
       temp.sp$presence.points <- test.data
 
       if(verbose){
-        test.evaluation <-dismo::evaluate(test.data, species$background.points[,1:2],
-                                          this.mx, env)
+        test.evaluation <-dismo::evaluate(test.data, species$background.points,
+                                          this.mx, env, na.rm = TRUE)
         env.test.evaluation <- env.evaluate(temp.sp, this.mx, env, n.background = env.nback)
       } else {
-        invisible(capture.output(test.evaluation <-dismo::evaluate(test.data, species$background.points[,1:2],
-                                          this.mx, env)))
+        invisible(capture.output(test.evaluation <-dismo::evaluate(test.data, species$background.points,
+                                          this.mx, env, na.rm = TRUE)))
         invisible(capture.output(env.test.evaluation <- env.evaluate(temp.sp, this.mx, env, n.background = env.nback)))
       }
 
@@ -146,7 +143,7 @@ enmtools.maxent <- function(species, env, test.prop = 0, nback = 1000, env.nback
   # Test eval for spatially structured data
   if(is.character(test.prop)){
     if(test.prop == "block"){
-      test.check <- raster::extract(env, test.data)
+      test.check <- terra::extract(env, test.data, ID = FALSE)
       test.data <- test.data[complete.cases(test.check),]
 
       temp.sp <- species
@@ -155,11 +152,11 @@ enmtools.maxent <- function(species, env, test.prop = 0, nback = 1000, env.nback
 
       if(verbose){
         test.evaluation <-dismo::evaluate(test.data, test.bg,
-                                          this.mx, env)
+                                          this.mx, env, na.rm = TRUE)
         env.test.evaluation <- env.evaluate(temp.sp, this.mx, env, n.background = env.nback)
       } else {
-        invisible(capture.output(test.evaluation <-dismo::evaluate(test.data, test.bg,
-                                          this.mx, env)))
+        invisible(capture.output(test.evaluation <- dismo::evaluate(test.data, test.bg,
+                                          this.mx, env, na.rm = TRUE)))
         invisible(capture.output(env.test.evaluation <- env.evaluate(temp.sp, this.mx, env, n.background = env.nback)))
       }
 
@@ -226,13 +223,13 @@ enmtools.maxent <- function(species, env, test.prop = 0, nback = 1000, env.nback
       # We have to do this to capture the "this is maxent version XXX message".
       if(verbose){
         thisrep.mx <- dismo::maxent(env, p = rts.df[rts.df$presence == 1,1:2], a = rts.df[rts.df$presence == 0,1:2], ...)
-        thisrep.model.evaluation <-dismo::evaluate(rep.species$presence.points[,1:2], species$background.points[,1:2],
-                                                   thisrep.mx, env)
+        thisrep.model.evaluation <- dismo::evaluate(rep.species$presence.points, species$background.points,
+                                                   thisrep.mx, env, na.rm = TRUE)
         thisrep.env.model.evaluation <- env.evaluate(rep.species, thisrep.mx, env, n.background = env.nback)
       } else {
         invisible(capture.output(thisrep.mx <- dismo::maxent(env, p = rts.df[rts.df$presence == 1,1:2], a = rts.df[rts.df$presence == 0,1:2], ...)))
-        invisible(capture.output(thisrep.model.evaluation <-dismo::evaluate(rep.species$presence.points[,1:2], species$background.points[,1:2],
-                                                   thisrep.mx, env)))
+        invisible(capture.output(thisrep.model.evaluation <- dismo::evaluate(rep.species$presence.points, species$background.points,
+                                                   thisrep.mx, env, na.rm = TRUE)))
         invisible(capture.output(thisrep.env.model.evaluation <- env.evaluate(rep.species, thisrep.mx, env, n.background = env.nback)))
       }
 
@@ -240,27 +237,27 @@ enmtools.maxent <- function(species, env, test.prop = 0, nback = 1000, env.nback
       rts.env.training[i] <- thisrep.env.model.evaluation@auc
 
       if(test.prop > 0 & test.prop < 1){
+        thisrep.test.evaluation <-dismo::evaluate(rep.test.data, rep.species$background.points,
+                                                  thisrep.mx, env, na.rm = TRUE)
         temp.sp <- rep.species
         temp.sp$presence.points <- rep.test.data
-
-        if(verbose){
-          thisrep.test.evaluation <-dismo::evaluate(rep.test.data, rep.species$background.points[,1:2],
-                                                    thisrep.mx, env)
-          thisrep.env.test.evaluation <- env.evaluate(temp.sp, thisrep.mx, env, n.background = env.nback)
-        } else {
-          invisible(capture.output(thisrep.test.evaluation <-dismo::evaluate(rep.test.data, rep.species$background.points[,1:2],
-                                                    thisrep.mx, env)))
-          invisible(capture.output(thisrep.env.test.evaluation <- env.evaluate(temp.sp, thisrep.mx, env, n.background = env.nback)))
-        }
+        thisrep.env.test.evaluation <- env.evaluate(temp.sp, thisrep.mx, env, n.background = env.nback)
 
         rts.geog.test[i] <- thisrep.test.evaluation@auc
         rts.env.test[i] <- thisrep.env.test.evaluation@auc
+
+        rts.models[[paste0("rep.",i)]] <- list(model = thisrep.mx,
+                                               training.evaluation = thisrep.model.evaluation,
+                                               env.training.evaluation = thisrep.env.model.evaluation,
+                                               test.evaluation = thisrep.test.evaluation,
+                                               env.test.evaluation = thisrep.env.test.evaluation)
+      } else {
+        rts.models[[paste0("rep.",i)]] <- list(model = thisrep.mx,
+                                               training.evaluation = thisrep.model.evaluation,
+                                               env.training.evaluation = thisrep.env.model.evaluation,
+                                               test.evaluation = NA,
+                                               env.test.evaluation = NA)
       }
-      rts.models[[paste0("rep.",i)]] <- list(model = thisrep.mx,
-                                             training.evaluation = thisrep.model.evaluation,
-                                             env.training.evaluation = thisrep.env.model.evaluation,
-                                             test.evaluation = thisrep.test.evaluation,
-                                             env.test.evaluation = thisrep.env.test.evaluation)
     }
 
     # Reps are all run now, time to package it all up
@@ -276,31 +273,40 @@ enmtools.maxent <- function(species, env, test.prop = 0, nback = 1000, env.nback
       rts.env.test.pvalue <- NA
     }
 
+    rts.geog.training <- data.frame(AUC = rts.geog.training)
+    rts.env.training <- data.frame(AUC = rts.env.training)
+    rts.geog.test <- data.frame(AUC = rts.geog.test)
+    rts.env.test <- data.frame(AUC = rts.env.test)
+
     # Making plots
-    training.plot <- qplot(rts.geog.training, geom = "histogram", fill = "density", alpha = 0.5) +
+    training.plot <- ggplot(rts.geog.training, aes(x = .data$AUC, fill = "density", alpha = 0.5)) +
+      geom_histogram(binwidth = 0.05) +
       geom_vline(xintercept = model.evaluation@auc, linetype = "longdash") +
-      xlim(0,1) + guides(fill = FALSE, alpha = FALSE) + xlab("AUC") +
+      xlim(-0.05,1.05) + guides(fill = "none", alpha = "none") + xlab("AUC") +
       ggtitle(paste("Model performance in geographic space on training data")) +
       theme(plot.title = element_text(hjust = 0.5))
 
-    env.training.plot <- qplot(rts.env.training, geom = "histogram", fill = "density", alpha = 0.5) +
-      geom_vline(xintercept = env.model.evaluation@auc, linetype = "longdash") +
-      xlim(0,1) + guides(fill = FALSE, alpha = FALSE) + xlab("AUC") +
-      ggtitle(paste("Model performance in environmental space on training data")) +
+    env.training.plot <- ggplot(rts.env.training, aes(x = .data$AUC, fill = "density", alpha = 0.5)) +
+      geom_histogram(binwidth = 0.05) +
+      geom_vline(xintercept = model.evaluation@auc, linetype = "longdash") +
+      xlim(-0.05,1.05) + guides(fill = "none", alpha = "none") + xlab("AUC") +
+      ggtitle(paste("Model performance in environment space on training data")) +
       theme(plot.title = element_text(hjust = 0.5))
 
     # Make plots for test AUC distributions
     if(test.prop > 0){
-      test.plot <- qplot(rts.geog.test, geom = "histogram", fill = "density", alpha = 0.5) +
-        geom_vline(xintercept = test.evaluation@auc, linetype = "longdash") +
-        xlim(0,1) + guides(fill = FALSE, alpha = FALSE) + xlab("AUC") +
+      test.plot <- ggplot(rts.geog.test, aes(x = .data$AUC, fill = "density", alpha = 0.5)) +
+        geom_histogram(binwidth = 0.05) +
+        geom_vline(xintercept = model.evaluation@auc, linetype = "longdash") +
+        xlim(-0.05,1.05) + guides(fill = "none", alpha = "none") + xlab("AUC") +
         ggtitle(paste("Model performance in geographic space on test data")) +
         theme(plot.title = element_text(hjust = 0.5))
 
-      env.test.plot <- qplot(rts.env.test, geom = "histogram", fill = "density", alpha = 0.5) +
-        geom_vline(xintercept = env.test.evaluation@auc, linetype = "longdash") +
-        xlim(0,1) + guides(fill = FALSE, alpha = FALSE) + xlab("AUC") +
-        ggtitle(paste("Model performance in environmental space on test data")) +
+      env.test.plot <- ggplot(rts.env.test, aes(x = .data$AUC, fill = "density", alpha = 0.5)) +
+        geom_histogram(binwidth = 0.05) +
+        geom_vline(xintercept = model.evaluation@auc, linetype = "longdash") +
+        xlim(-0.05,1.05) + guides(fill = "none", alpha = "none") + xlab("AUC") +
+        ggtitle(paste("Model performance in environment space on test data")) +
         theme(plot.title = element_text(hjust = 0.5))
     } else {
       test.plot <- NA
@@ -370,7 +376,7 @@ enmtools.maxent <- function(species, env, test.prop = 0, nback = 1000, env.nback
 }
 
 # Summary for objects of class enmtools.maxent
-summary.enmtools.maxent <- function(object, ...){
+summary.enmtools.maxent <- function(object, plot = TRUE, ...){
 
   cat("\n\nData table (top ten lines): ")
   print(kable(head(object$analysis.df, 10)))
@@ -399,7 +405,9 @@ summary.enmtools.maxent <- function(object, ...){
   cat("\n\nNotes:  \n")
   print(object$notes)
 
-  plot(object)
+  if(plot) {
+    plot(object)
+  }
 
 }
 
@@ -414,22 +422,23 @@ print.enmtools.maxent <- function(x, ...){
 plot.enmtools.maxent <- function(x, ...){
 
 
-  suit.points <- data.frame(rasterToPoints(x$suitability))
-  colnames(suit.points) <- c("Longitude", "Latitude", "Suitability")
+  suit.points <- data.frame(rasterToPoints2(x$suitability))
+  colnames(suit.points) <- c("x", "y", "Suitability")
+  test <- terra::as.data.frame(x$test.data, geom = "XY")
 
-  suit.plot <- ggplot(data = suit.points, aes_string(y = "Latitude", x = "Longitude")) +
-    geom_raster(aes_string(fill = "Suitability")) +
+  suit.plot <- ggplot(data = suit.points, aes(y = .data$y, x = .data$x)) +
+    geom_raster(aes(fill = .data$Suitability)) +
     scale_fill_viridis_c(option = "B", guide = guide_colourbar(title = "Suitability")) +
     coord_fixed() + theme_classic() +
     geom_point(data = x$analysis.df[x$analysis.df$presence == 1 &
-                                    x$analysis.df$Longitude > extent(x$suitability)[1] &
-                                    x$analysis.df$Longitude < extent(x$suitability)[2] &
-                                    x$analysis.df$Latitude > extent(x$suitability)[3] &
-                                    x$analysis.df$Latitude < extent(x$suitability)[4],],  aes_string(y = "Latitude", x = "Longitude"),
+                                    x$analysis.df$x > terra::ext(x$suitability)[1] &
+                                    x$analysis.df$x < terra::ext(x$suitability)[2] &
+                                    x$analysis.df$y > terra::ext(x$suitability)[3] &
+                                    x$analysis.df$y < terra::ext(x$suitability)[4],],  aes(y = .data$y, x = .data$x),
                pch = 21, fill = "white", color = "black", size = 2)
 
-  if(!(all(is.na(x$test.data)))){
-    suit.plot <- suit.plot + geom_point(data = x$test.data,  aes_string(y = "Latitude", x = "Longitude"),
+  if(inherits(x$test.data, "SpatVector")){
+    suit.plot <- suit.plot + geom_point(data = test,  aes(y = .data$y, x = .data$x),
                                         pch = 21, fill = "green", color = "black", size = 2)
   }
 
@@ -448,7 +457,7 @@ plot.enmtools.maxent <- function(x, ...){
 predict.enmtools.maxent <- function(object, env, maxpts = 1000, clamp = TRUE, ...){
 
   # Make a plot of habitat suitability in the new region
-  suitability <- invisible(capture.output(raster::predict(env, object$model, ...)))
+  suitability <- invisible(capture.output(terra::predict(env, object$model, na.rm = TRUE, ...)))
 
   # I'm actually not sure this is doing anything - I think maxent models are clamped by default
   if(clamp == TRUE){
@@ -456,16 +465,16 @@ predict.enmtools.maxent <- function(object, env, maxpts = 1000, clamp = TRUE, ..
     this.df <- as.data.frame(rbind(object$model@presence, object$model@absence))
 
     env <- clamp.env(this.df, env)
-    clamped.suitability <- invisible(capture.output(raster::predict(env, object$model, ...)))
+    clamped.suitability <- invisible(capture.output(terra::predict(env, object$model, na.rm = TRUE, ...)))
     clamping.strength <- clamped.suitability - suitability
     suitability <- clamped.suitability
   }
 
-  suit.points <- data.frame(rasterToPoints(suitability))
-  colnames(suit.points) <- c("Longitude", "Latitude", "Suitability")
+  suit.points <- data.frame(rasterToPoints2(suitability))
+  colnames(suit.points) <- c("x", "y", "Suitability")
 
-  suit.plot <- ggplot(data = suit.points,  aes_string(y = "Latitude", x = "Longitude")) +
-    geom_raster(aes_string(fill = "Suitability")) +
+  suit.plot <- ggplot(data = suit.points,  aes(y = .data$y, x = .data$x)) +
+    geom_raster(aes(fill = .data$Suitability)) +
     scale_fill_viridis_c(option = "B", guide = guide_colourbar(title = "Suitability")) +
     coord_fixed() + theme_classic()
 
@@ -500,24 +509,16 @@ maxent.precheck <- function(f, species, env){
 
   check.species(species)
 
-  if(!inherits(species$presence.points, "data.frame")){
-    stop("Species presence.points do not appear to be an object of class data.frame")
+  if(!inherits(species$presence.points, "SpatVector")){
+    stop("Species presence.points do not appear to be an object of class SpatVector")
   }
 
-  if(!inherits(species$background.points, "data.frame")){
-    stop("Species background.points do not appear to be an object of class data.frame")
+  if(!inherits(species$background.points, "SpatVector")){
+    stop("Species background.points do not appear to be an object of class SpatVector")
   }
 
-  if(!inherits(env, c("raster", "RasterLayer", "RasterStack", "RasterBrick"))){
+  if(!inherits(env, c("SpatRaster"))){
     stop("No environmental rasters were supplied!")
   }
-
-  if(ncol(species$presence.points) != 2){
-    stop("Species presence points do not contain longitude and latitude data!")
-  }
-
-  if(ncol(species$background.points) != 2){
-    stop("Species background points do not contain longitude and latitude data!")
-  }
 }
 
